NIXIO Python library documentation — Python reimplementation of NIXIO (http://g-node.github.io/nix/) 1.5.3 Release documentation

# NIXIO Python library documentation

The NIXIO module is the native python re-implementation of the NIX C++ library for the NIX data model.

The NIX data model allows to store fully annotated scientific datasets, i.e. the data together with its metadata within the same container. Our aim is to achieve standardization by providing a common/generic data structure for a multitude of data types. See the wiki or the introduction for more information.

The current implementations store the actual data using the HDF5 file format as a storage backend.

NIX emerged from the activities of the Electrophysiology Task Force of the INCF Datasharing Program (2010-2015). It is a registered research resource with the RRID:SCR_016196.

## Introduction

We have assembled introductory material that illustrates using nix. The tutorials contain several code examples. The use_cases explain in more detail how nix is used in real world situations.

## Support

If you need help, want to get in touch, or have any other request these are your options.

## Citing

If you use NIX, it would be much appreciated if you would cite it in publications with its identifier RRID:SCR_016196 and/or the reference:

Stoewer A, Kellner CJ, Benda J, Wachtler T and Grewe J (2014). File format and library for neuroscience data and metadata. Front. Neuroinform. Conference Abstract: Neuroinformatics 2014. doi: 10.3389/conf.fninf.2014.18.00027

## Referenced by

- Sinz et al. (2020) doi:10.1152/jn.00615.2019

- Buccino et al. (2019) doi:10.1101/796599

- Sprenger et al. (2019) doi:10.3389/fninf.2019.00062

- Dragly et al (2018) doi:10.3389/fninf.2018.000169

- Papez et al (2017) doi:10.3389/fninf.2017.00024

- Grewe et al (2017) doi:10.1073/pnas.1615561114

- Vanek et al (2016) doi:10.1109/informatics.2015.7377849

- Rübel et al (2016) doi:10.3389/fninf.2016.00048

- Denker et al (2016) doi:10.1007/978-3-319-50862-7_5

- Teeters et al (2015) doi:10.1016/j.neuron.2015.10.025

Introduction

- Idea
- Installation instructions
- Support for standardization
- Use-cases

Tutorials

- Tutorials